@@ -2,7 +2,9 @@ pub mod angle;
 pub mod declaration;
 pub mod easing_function;
 pub mod empty;
+pub mod frequency;
 pub mod keyframes;
 pub mod selector;
 pub mod time;
+pub mod transform_function;
 pub mod url;
